@@ -99,8 +99,9 @@ def main():
         sys.exit()
 
     if pargs.install_pythonocc_force:
+        import zencad.version
         from zencad.geometry_core_installer import install_precompiled_python_occ
-        install_precompiled_python_occ()
+        install_precompiled_python_occ(occversion=zencad.version.__pythonocc_version__)
         return
 
     if pargs.lookup_libraries:
@@ -109,20 +110,22 @@ def main():
         return
 
     if pargs.install_occt_force is not None:
+        import zencad.version
         from zencad.geometry_core_installer import install_precompiled_occt_library
         path = pargs.install_occt_force[0] if len(
             pargs.install_occt_force) > 0 else None
-        install_precompiled_occt_library(tgtpath=path)
+        install_precompiled_occt_library(tgtpath=path, occt_version=zencad.version.__occt_version__)
         return
 
     if pargs.install_occt_to_pythonocc_dir:
+        import zencad.version
         from zencad.geometry_core_installer import install_precompiled_occt_library
         import zencad.gui.util
         path = zencad.gui.util.pythonocc_core_directory()
         if path is None:
             print("PythonOCC is not installed")
             return -1
-        install_precompiled_occt_library(tgtpath=path)
+        install_precompiled_occt_library(tgtpath=path, occt_version=zencad.version.__occt_version__)
         return 0
 
     from zencad.showapi import widget_creator
